<?php //Admin Post: admin-post.php

add_action( 'admin_enqueue_scripts', 'blm_admin_post_scripts' );
add_action( 'admin_notices', 'blm_admin_post_notice' );
add_action( 'add_meta_boxes', 'blm_admin_post_location_display' );
add_action( 'save_post', 'blm_admin_post_save', 100, 3 );
add_filter( 'post_updated_messages', 'blm_admin_post_save_callback' );

/*
* blm_admin_post_scripts
* Add CSS and JS to the admin post page
*/
function blm_admin_post_scripts( $hook ) {

	// Check valid page type
	if( !blm_admin_post_validtype( $hook ) ) {
		return true;
	}

	// Get current Google API key
	$blm_setting_google_api_key = esc_attr( get_option( 'blm_setting_google_api_key' ) );

	// Load scripts if key is available
	if( $blm_setting_google_api_key ) {
		wp_enqueue_script( 'blm_meta_js_google', 'https://maps.googleapis.com/maps/api/js?key='.$blm_setting_google_api_key );
		wp_enqueue_script( 'blm_meta_js_geocode', plugins_url( 'js/geocode.js', __FILE__ ), null, '1.1' );
		wp_enqueue_script( 'blm_meta_js_adminpost', plugins_url( 'js/admin-post.js', __FILE__ ), array( 'jquery' ), '1.1' );
		wp_enqueue_style( 'blm_meta_css_main', plugins_url( 'css/admin-post.css', __FILE__ ), null, '1.1' );
	}

}// blm_admin_post_scripts

/*
* blm_admin_post_notice
* Add a message to the header of the admin
*/
function blm_admin_post_notice(){

	// Initialize
	global $pagenow, $post_ID;

	// Check valid page type
	if( !blm_admin_post_validtype( $pagenow ) ) {
		return true;
	}

	// Handle API response notice
	if( $api_response = get_post_meta( $post_ID, 'blm_savepost_response', true ) ){
		$api_response = json_decode( $api_response );
		echo '<div class="notice '.$api_response->notice_type.' is-dismissible" data-code="'.$api_response->code.'"><p>Bloom: '.$api_response->message.'</p></div>';
	}

	// Close any pending processes
	blm_admin_post_save_exit();

	return true;

}// blm_admin_post_notice

/*
* blm_admin_post_location_display
* Adds a location input to post editor
*/
function blm_admin_post_location_display() {

	// Initialize
	global $pagenow;

	// Check valid page type
	if( !blm_admin_post_validtype( $pagenow ) ) {
		return false;
	}

	// Check for Google API key
	if( !get_option( 'blm_setting_google_api_key' ) ) {
		return false;
	}

	// Check active post type
	if( 'none' === get_option( 'blm_setting_posttype_'.get_post_type( $post ) ) ) {
		return false;
	}

	// Display location form
	add_meta_box( 'blm_location_meta', __( 'Post Location', 'location-textdomain' ), 'blm_admin_post_location_display_callback', null, 'advanced', 'high' );

}// blm_admin_post_location_display

/*
* blm_admin_post_location_display_callback
* Displays the location input in editor
*/
function blm_admin_post_location_display_callback( $post ) {

	// Fetch currently-saved post location data
	$blm_setting_google_api_key = esc_attr( get_option( 'blm_setting_google_api_key' ) );
	$blm_post_key = get_post_meta( $post->ID, 'blm_post_key', true );
	$blm_post_location_formatted = get_post_meta( $post->ID, 'blm_post_location_formatted', true );
	$blm_post_location_components = get_post_meta( $post->ID, 'blm_post_location_components', true );
	$blm_post_location_latitude = get_post_meta( $post->ID, 'blm_post_location_latitude', true );
	$blm_post_location_longitude = get_post_meta( $post->ID, 'blm_post_location_longitude', true );

	// Handle if no Google API key provided
	if( !$blm_setting_google_api_key ) {
		echo '<p>Enter your Google API Key on the Bloom Settings page in order to use this geotagging feature.</p>';
		return true;
	}

	// If post is submitted, generate the map image
	if( $blm_post_location_latitude && $blm_post_location_longitude && $blm_post_key ) {
		blm_lib_map_image( $blm_post_location_latitude, $blm_post_location_longitude, $blm_post_key );
	}
	?>

	<div id="blm-meta-intro">The location selected here should define the location discussed in this post, if applicable.  By saving the location, the post is <a href="https://www.bloom.li/advocacy/metadata" title="Bloom" target="_blank">geotagged</a> by inserting the address and coordinates into the webpage metadata.</div>

	<div id="blm-location-selection-tool">
		<div id="blm-location-search">
			<div class="blm-search-title">Location Search</div>
			<div class="blm-search-body">
				<input type="text" id="blm-location-input" />
				<button type="button" id="blm-location-request" onClick="blmGeocode( 'blm-location-input', 'blm-location-results' );">Search</button>
				<div id="blm-location-results"></div>
			</div>
		</div>

		<div id="blm-location-choice" data-display="<?php echo ( $blm_post_location_formatted ) ? 1 : 0; ?>">
			<div class="blm-search-title">Location Selected<button type="button" id="blm-location-clear" onClick="blmClearLocation();">Clear</button><button type="button" id="blm-location-details" onClick="blmLocationDetailsChange('show');">Show Details</button></div>

			<div class="blm-search-body">
				<div id="blm-location-choice-value"><?php echo $blm_post_location_formatted; ?></div>
				<div id="blm-location-choice-components">
					<ul>
						<?php
						if( $blm_post_location_components ) {

							$blm_post_lc_array = json_decode( $blm_post_location_components );

							if( is_array($blm_post_lc_array) && !empty($blm_post_lc_array) ) {

								foreach( $blm_post_lc_array as $blm_post_lc_key => $blm_post_lc_value ) {

									if( ! $blm_post_lc_value ){
										$blm_post_lc_value = '<em>N/A</em>';
									}

									echo '<li><strong>'.ucfirst( str_replace( '_', ' ', $blm_post_lc_key ) ).':</strong> '.$blm_post_lc_value.'</li>';

								}

							}

						}
						?>
					</ul>
				</div>
				<input type="hidden" name="blm-formatted-address" id="blm-formatted-address" value="<?php echo $blm_post_location_formatted; ?>" />
				<input type="hidden" name="blm-address-components" id="blm-address-components" value="<?php echo base64_encode( $blm_post_location_components ); ?>" />
				<input type="hidden" name="blm-latitude" id="blm-latitude" value="<?php echo $blm_post_location_latitude; ?>" />
				<input type="hidden" name="blm-longitude" id="blm-longitude" value="<?php echo $blm_post_location_longitude; ?>" />
			</div>
		</div>
	</div>

<?php

}// blm_admin_post_location_display_callback

/*
* blm_admin_post_save
* Save the post to Bloom
*/
function blm_admin_post_save( $post_ID , $post, $update) {

	// Initialize
	global $pagenow;
	$has_location = false;
	$post_type_defaults = array('post', 'page', 'attachment', 'revision', 'nav_menu_item');
	$post_type = get_post_type( $post );

	// Check valid page type
	if( !blm_admin_post_validtype( $pagenow ) ) {
		return true;
	}

	// Check active post type
	$blm_post_type = get_option( 'blm_setting_posttype_'.$post_type );
	if($blm_post_type === 'none'){
		return false;
	}

	// Update location values

	if( isset( $_POST['blm-formatted-address'] ) && $_POST['blm-formatted-address'] ) {
		$has_location = true;
		update_post_meta( $post_ID, 'blm_post_location_formatted', sanitize_text_field( urldecode( $_POST['blm-formatted-address'] ) ) );
	}

	if( isset( $_POST['blm-address-components'] ) && $_POST['blm-address-components'] ) {
		$has_location = true;
		update_post_meta( $post_ID, 'blm_post_location_components', base64_decode( sanitize_text_field( $_POST['blm-address-components'] ) ) );
	}

	if( isset( $_POST['blm-latitude'] ) && $_POST['blm-latitude'] ) {
		$has_location = true;
		update_post_meta( $post_ID, 'blm_post_location_latitude', sanitize_text_field( $_POST['blm-latitude'] ) );
	}

	if( isset( $_POST['blm-longitude'] ) && $_POST['blm-longitude'] ) {
		$has_location = true;
		update_post_meta( $post_ID, 'blm_post_location_longitude', sanitize_text_field( $_POST['blm-longitude'] ) );
	}

	// Save to Bloom only if published
	if( 'publish' !== $post->post_status || !$has_location || wp_is_post_autosave( $post_ID ) ) {
		return blm_admin_post_save_exit();
	}

	// Get Bloom keys
	$blm_setting_bloom_api_key = get_option( 'blm_setting_bloom_api_key' );
	$blm_setting_bloom_publisher_key = get_option( 'blm_setting_bloom_publisher_key' );
	$blm_setting_google_api_key = get_option( 'blm_setting_google_api_key' );

	// Check key requirements
	if( !$blm_setting_bloom_api_key || !$blm_setting_bloom_publisher_key || !$blm_setting_google_api_key ) {

		// Process Bloom API call
		blm_lib_api_process( 'info', array(
			'app_action' => 'anon_geotagging',
			'url' => $_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI']
		) );

		// Update header message
		update_post_meta( $post_ID, 'blm_savepost_response', json_encode( array(
			'code' => 0,
			'message' => 'This post could not be geotagged with Bloom because your keys are not provided in the Settings.'
		) ) );

		return true;

	}

	// Get location data
	$blm_post_location_formatted = get_post_meta( $post_ID, 'blm_post_location_formatted', true );
	$blm_post_location_latitude = get_post_meta( $post_ID, 'blm_post_location_latitude', true );
	$blm_post_location_longitude = get_post_meta( $post_ID, 'blm_post_location_longitude', true );

	// Check location requirements
	if( !$blm_post_location_formatted || !$blm_post_location_latitude || !$blm_post_location_longitude ) {

		// Update header message
		update_post_meta( $post_ID, 'blm_savepost_response', json_encode( array(
			'code' => 0,
			'message' => 'This post could not be geotagged with Bloom because a valid location was not selected.'
		) ) );

		return true;

	}

	// Update pending field
	update_post_meta( $post_ID, 'blm_savepost_pending', 'true' );

	// Gather post data
	setup_postdata( $post );

	// Format publish date
	$blm_publish_date = get_the_date( 'Y-m-d H:i:s', $post_ID );

	// Check for custom publish date
	$blm_publish_date_custom = get_option( 'blm_setting_posttype_publishdate_' . $post_type );

	if( $blm_publish_date_custom ) {

		$blm_publish_date_custom_value = get_post_meta( $post_ID, $blm_publish_date_custom, true );

		if( !$blm_publish_date_custom_value && isset($_POST[$blm_publish_date_custom]) ) {
			$blm_publish_date_custom_value = $_POST[$blm_publish_date_custom];
		}

		if( $blm_publish_date_custom_value ) {

			// Format into date
			$blm_publish_date_custom_formatted = strtotime( $blm_publish_date_custom_value );
			if( $blm_publish_date_custom_formatted && $blm_publish_date_custom_formatted = date( 'Y-m-d H:i:s', $blm_publish_date_custom_formatted ) ) {
				$blm_publish_date = $blm_publish_date_custom_formatted;
			}

		}

	}

	// Check for custom fields
	$custom_fields = array();

	switch( $blm_post_type ){

		case 'event':

			// Get event end date
			$blm_end_date = get_option( 'blm_setting_posttype_enddate_' . $post_type );
			if( $blm_end_date && $blm_end_date_value = get_post_meta( $post_ID, $blm_end_date, true ) ) {

				// Format into date
				$blm_end_date_formatted = strtotime( $blm_end_date_value );
				if( $blm_end_date_formatted && $blm_end_date_formatted = date( 'Y-m-d H:i:s', $blm_end_date_formatted ) ) {
					$custom_fields['end_date'] = $blm_end_date_formatted;
				}

			}

			break;

	}

	$custom_fields = json_encode( $custom_fields );

	// Format expiration days
	$expiration_days = 'default';
	$expiration_days_custom = get_option( 'blm_setting_posttype_expiration_' . $post_type );
	if( $expiration_days_custom ) {
		$expiration_days = $expiration_days_custom;
	}

	// Format post data
        $query = array(
		'plugin_system' => 'wordpress',
                'plugin_version' => blm_lib_get_version(),
                'google_key' => $blm_setting_google_api_key,
                'app_key' => $blm_setting_bloom_api_key,
                'app_publisher' => $blm_setting_bloom_publisher_key,
                'app_action' => 'post_add',
                'key' => get_post_meta( $post_ID, 'blm_post_key', true ),
                'date' => $blm_publish_date,
                'expiration_days' => $expiration_days,
		'type' => $blm_post_type,
                'title' => get_the_title( $post ),
                'content' => get_the_excerpt( $post ),
                'content_full' => $post->post_content,
                'location_address' => $blm_post_location_formatted,
                'location_latitude' => $blm_post_location_latitude,
                'location_longitude' => $blm_post_location_longitude,
                'url' => get_permalink( $post ),
                'image_url' => get_the_post_thumbnail_url( $post, 'large' ),
                'user_agent' => $_SERVER['HTTP_USER_AGENT'],
		'custom_fields' => $custom_fields
        );

	// Process Bloom API call
	update_post_meta( $post_ID, 'blm_savepost_response', blm_lib_api_process( 'post', $query ) );

}// blm_admin_post_save

/*
* blm_admin_post_save_callback
* Add a message to the header of the admin
*/
function blm_admin_post_save_callback( $messages ) {

	global $pagenow, $post, $post_ID;

	// Check valid page type
	if( !blm_admin_post_validtype( $pagenow ) ) {
		return true;
	}

	// Handle if post is not awaiting to be saved
	if( 'true' !== get_post_meta( $post_ID, 'blm_savepost_pending', true ) ) {
		blm_admin_post_save_exit();
		return $messages;
	}

	// Decode the API response
	$api_response_raw = get_post_meta( $post_ID, 'blm_savepost_response', true );

	if( !$api_response_raw ) {
		blm_lib_error( 'api_response', $api_response_raw );
		blm_admin_post_save_exit();
		return $messages;
	}

	$api_response = json_decode( utf8_encode ( strip_tags( $api_response_raw ) ), true );
	if( !$api_response || !isset( $api_response['code'] ) ) {
		blm_lib_error( 'api_jsondecode', $api_response_raw );
		blm_admin_post_save_exit();
		return $messages;
	}

	$api_response['code'] = (int) $api_response['code'];

	// Handle type of response
	if( 1 === $api_response['code'] ) {

		// Handle successful response
		$api_response['notice_type'] = 'updated notice-success';

		//Save post key
		update_post_meta( $post_ID, 'blm_post_key', $api_response['data']['key'] );

		//Save post categories
		if(isset($api_response['data']['categories']) && !empty($api_response['data']['categories'])){
			update_post_meta( $post_ID, 'blm_post_categories', implode(';', $api_response['data']['categories']) );
		}

	} else {

		// Handle if post key is available to update
		if( isset( $api_response['data'] ) && isset( $api_response['data']['key'] ) && $api_response['data']['key'] ){
			update_post_meta( $post_ID, 'blm_post_key', $api_response['data']['key'] );
			blm_admin_post_save_exit();
			return $messages;
		}

		// Handle failed response
		$api_response['notice_type'] = 'notice-error';

	}

	// Save API response data
	update_post_meta( $post_ID, 'blm_savepost_response', json_encode( $api_response ) );

	return $messages;

}// blm_admin_post_save_callback

/*
* blm_admin_post_validtype
* Check for a valid page type
*/
function blm_admin_post_validtype($page){

	// Ignore if invalid page type
	if( 'post.php' !== $page && 'post-new.php' !== $page ) {
		return false;
	}

	return true;

}//blm_admin_post_validtype

/*
* blm_admin_post_save_exit
* Exit the post save process
*/
function blm_admin_post_save_exit() {

	global $post_ID;

	// Remove temporary meta fields
	delete_post_meta( $post_ID, 'blm_savepost_pending' );
	delete_post_meta( $post_ID, 'blm_savepost_response' );

	return true;

}// blm_admin_post_save_exit

?>
