<?php //Search: search.php

global $blm_settings;
$blm_settings = array();

add_action( 'wp_footer', 'blm_search_footer', 100 );
add_action( 'wp_enqueue_scripts', 'blm_search_scripts' );

/*
* blm_search_footer
* Add search to the footer of the website
*/
function blm_search_footer() {

	// Check requirements
	if( !blm_search_auth() ) {
		return true;
	}

	// Get plugin settings
	$blm_settings = blm_plugin_settings_read();

	if( !$blm_settings ) {
		return false;
	}

	// Add plugin
	echo '<bloom data-plugin="' . $blm_settings['key'] . '" data-color="' . $blm_settings['color'] . '" data-google-key="' . esc_attr( get_option( 'blm_setting_google_api_key' ) ) . '"></bloom>';

}// blm_search_footer

/*
* blm_write_plugin_settings
* Save plugin settings to the server
*/
function blm_plugin_settings_write() {

	// Get application style
	global $blm_settings;
	$api_response = blm_lib_api_process( 'application', array (
		'app_key' => get_option( 'blm_setting_bloom_api_key' ),
		'publisher_key' => get_option( 'blm_setting_bloom_publisher_key' ),
		'app_action' => 'get_search_plugin'
	) );

	// Handle error
	if( !$api_response ) {
		return false;
	}

	// Decode response
	$api_response = json_decode( $api_response );

	// Handle error
	if( !$api_response->success ) {
		return false;
	}

	// Further decode response
	$blm_settings = $api_response->message;
	$blm_settings = (array)$blm_settings;
	$blm_settings_encoded = json_encode( $blm_settings );
	$blm_settings_encoded = base64_encode( $blm_settings_encoded );

	// Save settings to file
	$blm_settings_file = plugin_dir_path( __FILE__ ) . '/settings.txt';
	$blm_settings_file_handle = fopen( $blm_settings_file, "w" );
	fwrite( $blm_settings_file_handle, $blm_settings_encoded );
	fclose( $blm_settings_file_handle );

	return $blm_settings;

}// blm_plugin_settings_write

/*
* blm_plugin_settings_read
* Get the plugin settings
*/
function blm_plugin_settings_read() {

	// Initialize
	$blm_settings_file = plugin_dir_path( __FILE__ ) . '/settings.txt';

	// Handle if file doesn't exist
	if( !file_exists( $blm_settings_file ) ) {

		// Get settings from Bloom
		$blm_settings = blm_plugin_settings_write();

		return $blm_settings;

	}

	// Get settings from file
	$blm_settings_file_handle = fopen( $blm_settings_file, "r" );

	// Get file contents
	$blm_settings = fread( $blm_settings_file_handle, filesize( $blm_settings_file ) );

	// Handle empty file
	if( !$blm_settings ) {

		// Get settings from Bloom
		$blm_settings = blm_plugin_settings_write();

		return $blm_settings;

	}

	// Decode settings from file
	$blm_settings = base64_decode( $blm_settings );
	$blm_settings = json_decode( $blm_settings, true );

	return $blm_settings;

}// blm_plugin_settings_read

/*
* blm_plugin_settings_refresh
* Refresh the plugin settings
*/
function blm_plugin_settings_refresh() {

	// Initialize
	$blm_settings_file = plugin_dir_path( __FILE__ ) . '/settings.txt';

	// Remove settings file
	if( file_exists( $blm_settings_file ) ) {
		unlink( $blm_settings_file );
	}

	// Save settings file
	blm_plugin_settings_write();

	return true;

}// blm_plugin_settings_refresh

/*
* blm_search_scripts
* Add CSS and JS to the plugin
*/
function blm_search_scripts() {

	// Check requirements
	if( !blm_search_auth() ) {
		return true;
	}

	// Set Google script if key provided
	$blm_setting_google_api_key = esc_attr( get_option( 'blm_setting_google_api_key' ) );
	if( $blm_setting_google_api_key ) {
		wp_enqueue_script( 'blm_search_js_geo', 'https://maps.googleapis.com/maps/api/js?key='.$blm_setting_google_api_key );
	}

	// Set other scripts
	wp_enqueue_script( 'blm_search_js',  plugins_url( 'js/search.js', __FILE__ ), array( 'jquery' ), "1.3", true );
	wp_enqueue_style( 'blm_search_css', plugins_url( 'css/search.css', __FILE__ ), array(), "1.1", "all" );

}// blm_search_scripts

/*
*blm_search_auth
*Authenticate the display of the plugin
*/
function blm_search_auth() {

	//Ignore if plugin key is not provided
	if( !get_option( 'blm_setting_bloom_api_key' ) ) {
		return false;
	}

	//Ignore if search is not enabled or if preview is disabled or if user is not logged in
	if( 'true' === get_option( 'blm_setting_search_enabled' ) ) {
		return true;
	}

	if( 'false' === get_option( 'blm_setting_search_preview' ) ) {
		return false;
	}

	if( !is_user_logged_in() ) {
		return false;
	}

	//Get logged in user
	$user = wp_get_current_user();

	//Compare against allowed roles
	$role_diff = array_udiff(
		$user->roles,
		array( 'administrator', 'editor', 'contributor', 'author' ),
		'strcasecmp'
	);

	if( empty( $role_diff ) ) {
		return true;
	}

	return true;

}//blm_search_auth

?>
